Fabric Bolt
===========

A web interface for fabric deployments.

Build Status
------------

.. image:: https://travis-ci.org/worthwhile/fabric-bolt.png?branch=develop
        :target: https://travis-ci.org/worthwhile/fabric-bolt

Quickstart
----------

1. Install::

    pip install fabric-bolt

2. Initialize settings file::

    fabric-bolt init [--conf=~/.fabric-bolt/settings.py]

3. Modify generated settings file to enter database settings.

4. Migrate db::

    fabric-bolt syncdb --migrate

5. Run::

    fabric-bolt runserver


Examples Screens
----------------

.. image:: docs/images/Screen Shot 2013-09-29 at 7.34.45 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.35.16 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.35.44 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.35.55 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.36.06 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.36.28 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.37.19 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.37.29 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.37.35 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.37.42 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.37.48 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.37.54 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.38.03 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.38.25 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.40.08 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.40.24 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.40.34 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.41.53 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.42.18 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.42.30 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.42.37 PM.png
.. image:: docs/images/Screen Shot 2013-09-29 at 7.43.28 PM.png

Authors
-------

* Dan Dietz
* Jared Proffitt
* Nathaniel Pardington
